@@ -18,6 +18,7 @@ import (
 	"github.com/lmorg/murex/shell/history"
 	"github.com/lmorg/murex/utils"
 	"github.com/lmorg/murex/utils/ansi"
+	"github.com/lmorg/murex/utils/ansititle"
 	"github.com/lmorg/murex/utils/cd"
 	"github.com/lmorg/murex/utils/cd/cache"
 	"github.com/lmorg/murex/utils/consts"
@@ -118,6 +119,11 @@ func ShowPrompt() {
 	}
 
 	for {
+		v, err := lang.ShellProcess.Config.Get("proc", "echo-tmux", types.Boolean)
+		if tmux, ok := v.(bool); ok && err == nil && tmux {
+			ansititle.Tmux([]byte(app.Name))
+		}
+
 		signalRegister(true)
 
 		setPromptHistory()
@@ -140,6 +146,7 @@ func ShowPrompt() {
 		if nLines > 1 {
 			prompt = getMultilinePrompt(nLines)
 		} else {
+			prePostPromptFunction("pre")
 			block = []rune{}
 			prompt = getPrompt()
 			writeTitlebar()
@@ -236,6 +243,8 @@ func ShowPrompt() {
 			nLines = 1
 			merged = ""
 
+			prePostPromptFunction("post")
+
 			fork := lang.ShellProcess.Fork(lang.F_PARENT_VARTABLE | lang.F_NEW_MODULE | lang.F_NO_STDIN)
 			fork.FileRef = &ref.File{Source: &ref.Source{Module: app.ShellModule}}
 			fork.Stderr = term.NewErr(ansi.IsAllowed())
